/**
 ******************************************************************************
 * Name: SAXMoviesHandler                                                     *                                
 * Description: SAX handler class used to compute the avg rating of a movie   *
 * @author  Fabio Arciniegas A.
 ******************************************************************************
 
 ******************************************************************************


|<---            this code is formatted to fit into 80 columns             --->|

 */


// ******************************************                            Imports
import org.xml.sax.Parser;
import org.xml.sax.XMLReader;
import org.xml.sax.HandlerBase;
import org.xml.sax.AttributeList;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;
import org.xml.sax.helpers.ParserFactory;



// ******************************************                   Class Definition
public class SAXMoviesHandler extends HandlerBase
{

    /** Default parser name. */
    private static final String 
    DEFAULT_PARSER_NAME = "org.apache.xerces.parsers.SAXParser";

// ******************************************               SAX specific methods

/**
 * Since the ratings are expressed as an attribute of the review element, All 
 * we have to do is check the startElement method
 * @see DocumentHandler
 */
    public void startElement(String name, AttributeList atts)
    {
	if(name.compareTo("review") == 0)
	    average = (numberOfReviews*average + 
                       new Integer(atts.getValue(0)).intValue()) /  ++numberOfReviews;

	    // Purists may argue that this is an indecent way to calculate
	    // the average because of precision issues. However, our focus
	    // here is on SAX, not on Numeric Analysis, so simplicity takes
	    // precedence! :)
    }

    public void endElement(String name)
    {
	if(name.compareTo("movie") == 0)
	    System.out.println("The average rating for this movie is "
                               + average);
    }

    private float average;           // for the movie 
    private int   numberOfReviews;   // for the movie 

    public static void main(String argv[])
    {
        if (argv.length == 0) 
	{
	    System.out.println("No files specified");
            System.exit(1);
        }
	try 
	{

            SAXMoviesHandler moviesHandler = new SAXMoviesHandler();

            Parser parser = ParserFactory.makeParser(DEFAULT_PARSER_NAME);
	    parser.setDocumentHandler(moviesHandler);
	    parser.parse(argv[0]);
	}
	catch (Exception ex) 
	{
	    System.err.println("there is something."); 
            ex.printStackTrace(System.err);
        }
    }
};




